==> kubernetes-model-1.0.40-sources.jar: io/fabric8/kubernetes/api/model/extensions/ThirdPartyResourceBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.ArrayList;
import java.util.Map;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class ThirdPartyResourceBuilder extends ThirdPartyResourceFluentImpl<ThirdPartyResourceBuilder> implements VisitableBuilder<ThirdPartyResource,ThirdPartyResourceBuilder>{

     ThirdPartyResourceFluent<?> fluent;
public ThirdPartyResourceBuilder(){
    this(new ThirdPartyResource());
}
public ThirdPartyResourceBuilder( ThirdPartyResourceFluent<?> fluent ){
    this(fluent, new ThirdPartyResource());
}
public ThirdPartyResourceBuilder( ThirdPartyResourceFluent<?> fluent , ThirdPartyResource instance ){
    this.fluent = fluent; fluent.withApiVersion(instance.getApiVersion()); fluent.withDescription(instance.getDescription()); fluent.withKind(instance.getKind()); fluent.withMetadata(instance.getMetadata()); fluent.withVersions(instance.getVersions()); 
}
public ThirdPartyResourceBuilder( ThirdPartyResource instance ){
    this.fluent = this; this.withApiVersion(instance.getApiVersion()); this.withDescription(instance.getDescription()); this.withKind(instance.getKind()); this.withMetadata(instance.getMetadata()); this.withVersions(instance.getVersions()); 
}

public EditableThirdPartyResource build(){
    EditableThirdPartyResource buildable = new EditableThirdPartyResource(fluent.getApiVersion(),fluent.getDescription(),fluent.getKind(),fluent.getMetadata(),fluent.getVersions());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ThirdPartyResourceBuilder that = (ThirdPartyResourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/kubernetes/api/model/extensions/ThirdPartyResourceBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.List;
import java.util.ArrayList;
import java.util.RandomAccess;
import io.fabric8.kubernetes.api.model.HasMetadata;
import java.util.Map;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import java.util.Map;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class ThirdPartyResourceBuilder extends ThirdPartyResourceFluentImpl<ThirdPartyResourceBuilder> implements VisitableBuilder<ThirdPartyResource,ThirdPartyResourceBuilder>{

     ThirdPartyResourceFluent<?> fluent;
public ThirdPartyResourceBuilder(){
    this(new ThirdPartyResource());
}
public ThirdPartyResourceBuilder( ThirdPartyResourceFluent<?> fluent ){
    this(fluent, new ThirdPartyResource());
}
public ThirdPartyResourceBuilder( ThirdPartyResourceFluent<?> fluent , ThirdPartyResource instance ){
    this.fluent = fluent; fluent.withApiVersion(instance.getApiVersion()); fluent.withDescription(instance.getDescription()); fluent.withKind(instance.getKind()); fluent.withMetadata(instance.getMetadata()); fluent.withVersions(instance.getVersions()); 
}
public ThirdPartyResourceBuilder( ThirdPartyResource instance ){
    this.fluent = this; this.withApiVersion(instance.getApiVersion()); this.withDescription(instance.getDescription()); this.withKind(instance.getKind()); this.withMetadata(instance.getMetadata()); this.withVersions(instance.getVersions()); 
}

public ThirdPartyResource build(){
    ThirdPartyResource buildable = new ThirdPartyResource(fluent.getApiVersion(),fluent.getDescription(),fluent.getKind(),fluent.getMetadata(),fluent.getVersions());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ThirdPartyResourceBuilder that = (ThirdPartyResourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}
